jk_dirwalker
==========

Introduction
------------

This python module ...

Information about this module can be found here:

* [github.org](https://github.com/jkpubsrc/....)
* [pypi.python.org](https://pypi.python.org/pypi/jk_dirwalker)

Why this module?
----------------

...

Limitations of this module
--------------------------

...

How to use this module
----------------------

### Import this module

Please include this module into your application using the following code:

```python
import jk_dirwalker
```

...

Contact Information
-------------------

* Jürgen Knauth: pubsrc@binary-overflow.de

License
-------

This software is provided under the following license:

* Apache Software License 2.0



